pub struct BadBlock2Option;
Error that occurs when constructing a Block2RequestData from a message or an option.
It is singular and contains no details (for there is no usable action from them), but usually
stems from either the option being repeated or having an excessively large value.
Formats the value using the given formatter. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.